"""
nhanes_get_dataset_info

Get information about NHANES (National Health and Nutrition Examination Survey) datasets. NHANES ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def nhanes_get_dataset_info(
    year: Optional[str] = None,
    component: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get information about NHANES (National Health and Nutrition Examination Survey) datasets. NHANES ...

    Parameters
    ----------
    year : str
        NHANES cycle/year (e.g., '2017-2018', '2015-2016', '2013-2014')
    component : str
        Optional component type to filter datasets
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "nhanes_get_dataset_info",
            "arguments": {"year": year, "component": component},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["nhanes_get_dataset_info"]
